Needing help?

- Enter your query in the input field. Make sure that attributes mentioned in the query are existent in the listed attributes underneath the input field
- (Optional) Select attributes. Each GBD-Hash which matches your query is resolved against these attributes. This affects the values shown in the table and given in the csv file ("Download attributes")
- Press the enter button or press the search button right next to the input field to populate the table with your results.
- You can download the result of the query as csv file or get a list of URLs for the instances to download them